@@ -14,7 +14,7 @@
 #' 
 #' @param dataarray Input k x m x n real array, where k is the number of
 #' points, m is the number of dimensions, and n is the sample size.
-#' @param scale logical: indicating if scaling is requested
+#' @param scale logical: indicating if scaling is requested to minimize the General Procrustes distance. To avoid all scaling, one has to set \code{CSinit=FALSE}, too.
 #' @param reflect logical: allow reflections.
 #' @param CSinit logical: if TRUE, all configurations are initially scaled to
 #' Unit Centroid Size.
@@ -199,7 +199,7 @@ procSym <- function(dataarray, scale=TRUE, reflect=TRUE, CSinit=TRUE,  orp=TRUE,
         for (i in 1:dim(Aall)[3]) {
             tmp[,,i] <- rotonmat(Aall[,,i],Aall[use.lm,,i],proc$rotated[,,i],scale=TRUE, reflection=reflect)
             if (center.part)
-                tmp[,,i] <- apply(tmp[,,i],2,scale,scale=F) ## center shapes
+                tmp[,,i] <- scale(tmp[,,i], scale=FALSE) ## center shapes
             else
                 orp <- FALSE
         }
@@ -351,3 +351,22 @@ procSym <- function(dataarray, scale=TRUE, reflect=TRUE, CSinit=TRUE,  orp=TRUE,
     return(out)
     
 }
+#' @export       
+print.nosymproc <- function(x,...) {
+    cat(paste0(" No. of Specimens: ",dim(x$rotated)[3],"\n"))
+        cat(paste0(" ",dim(x$rotated)[1]," Landmarks in ", dim(x$rotated)[2]," dimensions\n"))
+    cat("\n Variance Table\n")
+    print(as.data.frame(x$Var),row.names=FALSE)
+}
+    
+#' @export       
+print.symproc <- function(x,...) {
+    cat(paste0(" No. of Specimens: ",dim(x$rotated)[3],"\n"))
+    cat(paste0(" ",dim(x$rotated)[1]," Landmarks in ", dim(x$rotated)[2]," dimensions\n"))
+    cat(paste0("    - of which there are ",dim(x$pairedLM)[1]," sets of paired Landmarks\n"))
+    cat("\n Variance Table of Symmetric Component\n")
+    print(as.data.frame(x$SymVar),row.names=FALSE)
+    cat("\n Variance Table of Asymmetric Component\n")
+    print(as.data.frame(x$AsymVar),row.names=FALSE)
+}
+    
