@@ -62,6 +62,7 @@
 #' projected onto the surface. If you have landmarks not on the surface, select
 #' \code{fixRepro=FALSE}
 #' @param missingList a list of length samplesize containing integer vectors of row indices specifying missing landmars for each specimen. For specimens without missing landmarks enter \code{numeric(0)}.
+#' @param use.lm indices specifying a subset of (semi-)landmarks to be used in the rotation step - only used if \code{bending=FALSE}.
 #' @return
 #' \item{dataslide }{array containing slidden Landmarks in the original
 #' space - not yet processed by a Procrustes analysis}
@@ -96,7 +97,7 @@
 #' \dontrun{
 #' data(nose)
 #' ###create mesh for longnose
-#' longnose.mesh <- warp.mesh(shortnose.mesh,shortnose.lm,longnose.lm)
+#' longnose.mesh <- tps3d(shortnose.mesh,shortnose.lm,longnose.lm)
 #' ### write meshes to disk
 #' mesh2ply(shortnose.mesh, filename="shortnose")
 #' mesh2ply(longnose.mesh, filename="longnose")
@@ -139,7 +140,7 @@
 #' }
 #' 
 #' @export
-slider3d <- function(dat.array,SMvector,outlines=NULL,surp=NULL,sur.path="sur",sur.name=NULL, meshlist=NULL, ignore=NULL,sur.type="ply",tol=1e-05,deselect=FALSE,inc.check=TRUE,recursive=TRUE,iterations=0,initproc=TRUE,fullGPA=FALSE,pairedLM=0,bending=TRUE,stepsize=ifelse(bending,1,0.5),mc.cores = parallel::detectCores(), fixRepro=TRUE,missingList=NULL)
+slider3d <- function(dat.array,SMvector,outlines=NULL,surp=NULL,sur.path="sur",sur.name=NULL, meshlist=NULL, ignore=NULL,sur.type="ply",tol=1e-05,deselect=FALSE,inc.check=TRUE,recursive=TRUE,iterations=0,initproc=TRUE,fullGPA=FALSE,pairedLM=0,bending=TRUE,stepsize=ifelse(bending,1,0.5),mc.cores = parallel::detectCores(), fixRepro=TRUE,missingList=NULL,use.lm=NULL)
 {
     if(.Platform$OS.type == "windows")
         mc.cores <- 1
@@ -216,6 +217,11 @@ slider3d <- function(dat.array,SMvector,outlines=NULL,surp=NULL,sur.path="sur",s
     else
         fixRepro <- TRUE
 
+    weights <- NULL
+    if (!is.null(use.lm)) {
+        weights <- rep(0,dim(dat.array)[1])
+        weights[use.lm] <- 1
+    }
     if(length(sur.name)==0) {
         sur.name <- dimnames(dat.array)[[3]]
         sur.name <- paste(sur.path,"/",sur.name,".",sur.type,sep="")
@@ -305,7 +311,7 @@ slider3d <- function(dat.array,SMvector,outlines=NULL,surp=NULL,sur.path="sur",s
                 tmpdata <- dat.array[,,j]
                 tmpvn <- vn.array[,,j]
                 if (!bending) {
-                    rot <- rotonto(mshape,tmpdata,reflection=FALSE,scale=TRUE)
+                    rot <- rotonto(mshape,tmpdata,reflection=FALSE,scale=TRUE,weights=weights,centerweight=TRUE)
                     tmpdata <- rot$yrot
                     tmpvn <- tmpvn%*%rot$gamm
                 }
